#include <cstdio>
#include <algorithm>
#include <set>

struct point
{
    int x, y;
    bool operator<(const point &b) const
    {
        return (y == b.y) ? x < b.x : y < b.y; // careful with set<>: different elements must compare different, even though we don't care about the x-coordinates
    }
};

bool byX(const point &a, const point &b)
{
    return a.x < b.x;
}

const int MAXN = 200000 + 10;

int W, H, S, N;
point p[MAXN];
std::set<point> active;

void read()
{
    scanf("%d%d%d", &W, &H, &S);
    scanf("%d", &N);
    for (int i = 0; i < N; i++)
    {
        scanf("%d%d", &p[i].x, &p[i].y);
        if (p[i].x > 0 && p[i].x < S)
        {
            active.insert(p[i]);
        }
    }
    std::sort(p, p + N, byX);
}

bool solve()
{
    // corner case: tent is on the left edge of the field
    if (active.size() == 0)
    {
        return true;
    }
    int lastY = 0;
    for (std::set<point>::iterator it = active.begin(); it != active.end(); it++)
    {
        if (it->y - lastY >= S)
        {
            return true;
        }
        lastY = it->y;
    }
    if (H - lastY >= S)
    {
        return true;
    }
    
    // sweep
    int head = 0, tail = 0;
    while (head < N && p[head].x == 0)
    {
        head++;
    }
    while (tail < N && p[tail].x < S)
    {
        tail++;
    }
    for (; head < N && p[head].x + S <= W; head++)
    {
        while (tail < N && p[tail].x < p[head].x + S)
        {
            active.insert(p[tail]);
            tail++;
        }
        int lowY = 0;
        std::set<point>::iterator it = active.find(p[head]), border;
        if (it != active.begin())
        {
            border = it;
            border--;
            lowY = border->y;
        }
        int highY = H;
        border = it;
        border++;
        if (border != active.end())
        {
            highY = border->y;
        }
        if (highY - lowY >= S)
        {
            return true;
        }
        active.erase(p[head]);
    }
    
    return false;
}

int main()
{
    read();
    bool can = solve();
    if (can)
    {
        printf("YES\n");
    }
    else
    {
        printf("NO\n");
    }
    
    return 0;
}
