
#include <cstdio>
#include <vector>
#include <cassert>
#include <cstdlib>
#include <string>
#include <sstream>
#include <iostream>
#include <algorithm>
using namespace std;

struct Vertex {
	int value;
	int minValue;
	int maxValue;
	int subtreeSize;
	bool reversed;
	Vertex* leftChild;
	Vertex* rightChild;
	
	void reverse() {
		if (reversed) {
			Vertex* swapVertex = leftChild;
			leftChild = rightChild;
			rightChild = swapVertex;
			reversed = false;
			
			if (leftChild != NULL)
				leftChild->reversed = !leftChild->reversed;
			if (rightChild != NULL)
				rightChild->reversed = !rightChild->reversed;
		}
	}
	
	void fullReverse() {
		reverse();
		if (leftChild != NULL)
			leftChild->fullReverse();
		if (rightChild != NULL)
			rightChild->fullReverse();
	}
	
	void dfs(vector<int> &seq) {
		if (leftChild != NULL)
			leftChild->dfs(seq);
		seq.push_back(value);
		if (rightChild != NULL)
			rightChild->dfs(seq);
	}
};

inline Vertex* createTree(int value) {
	Vertex* root = new Vertex();
	root->value = value;
	root->minValue = value;
	root->maxValue = value;
	root->subtreeSize = 1;
	root->reversed = false;
	root->leftChild = NULL;
	root->rightChild = NULL;
	return root;
}

inline int getSizeOfTree(Vertex *root) {
	return (root == NULL) ? 0 : root->subtreeSize;
}

inline void update(Vertex *root) {
	if (root == NULL)
		return;
	root->minValue = root->value;
	root->maxValue = root->value;
	root->subtreeSize = 1;
	if (root->leftChild != NULL) {
		root->minValue = min(root->minValue, root->leftChild->minValue);
		root->maxValue = max(root->maxValue, root->leftChild->maxValue);
		root->subtreeSize += root->leftChild->subtreeSize;
	}
	if (root->rightChild != NULL) {
		root->minValue = min(root->minValue, root->rightChild->minValue);
		root->maxValue = max(root->maxValue, root->rightChild->maxValue);
		root->subtreeSize += root->rightChild->subtreeSize;
	}
}

Vertex* mergeTrees(Vertex* leftChild, Vertex* rightChild) {
	if (leftChild == NULL)
		return rightChild;
	if (rightChild == NULL)
		return leftChild;
	
	leftChild->reverse();
	rightChild->reverse();
	int leftSubtreeSize = getSizeOfTree(leftChild);
	int rightSubtreeSize = getSizeOfTree(rightChild);
	Vertex* root;
	if (rand() % (leftSubtreeSize + rightSubtreeSize) < leftSubtreeSize) {
		leftChild->rightChild = mergeTrees(leftChild->rightChild, rightChild);
		root = leftChild;
	} else {
		rightChild->leftChild = mergeTrees(leftChild, rightChild->leftChild);
		root = rightChild;
	}
	update(root);
	return root;
}

void splitTrees(Vertex **leftChild, Vertex **rightChild, Vertex *root, int splitIndex) {
	if (root == NULL) {
		*leftChild = NULL;
		*rightChild = NULL;
		return;
	}
	
	root->reverse();
	int rootIndex = getSizeOfTree(root->leftChild) + 1;
	
	if (rootIndex < splitIndex) {
		*leftChild = root;
		splitTrees(&((*leftChild)->rightChild), rightChild, root->rightChild, splitIndex - rootIndex);
	} else if (rootIndex > splitIndex) {
		*rightChild = root;
		splitTrees(leftChild, &((*rightChild)->leftChild), root->leftChild, splitIndex);
	} else {
		*leftChild = root;
		*rightChild = root->rightChild;
		root->rightChild = NULL;
	}
	update(*leftChild);
	update(*rightChild);
}
	
Vertex* buildTree(vector<int> &seq) {
	Vertex* root = NULL;
	for (int i = 0; i < int(seq.size()); ++i) {
		root = mergeTrees(root, createTree(seq[i]));
	}
	return root;
}

Vertex* applyReversal(Vertex* root, int first, int last) {
	Vertex *alpha, *beta, *gamma, *delta;
	splitTrees(&delta, &gamma, root, last);
	splitTrees(&alpha, &beta, delta, first - 1);
	beta->reversed = !beta->reversed;
	root = mergeTrees(alpha, beta);
	root = mergeTrees(root, gamma);
	return root;
}

int getIndexOfMax(Vertex *root) {	
	int value = root->maxValue;
//	printf("maxValue = %d\n", value);
//	printf("size = %d\n", root->subtreeSize);
	int index = 0;
	Vertex *at = root;
	while (true) {
		assert(at != NULL);
		assert(at->maxValue == value);
//		printf("at->value = %d\n", at->value);
//		printf("index = %d\n", index);
		at->reverse();
		int leftSubtreeSize = getSizeOfTree(at->leftChild);
		int rightSubtreeSize = getSizeOfTree(at->rightChild);
		if (at->value == value) {
			index += leftSubtreeSize + 1;
			break;
		} else if (leftSubtreeSize > 0 && at->leftChild->maxValue == value) {
			at = at->leftChild;
		} else if (rightSubtreeSize > 0 && at->rightChild->maxValue == value) {
			index += leftSubtreeSize + 1;
			at = at->rightChild;
		} else {
			assert(false);
		}
	}
//	printf("index = %d\n", index);
//	assert(false);
	return index;
}

vector<int> getSequence(Vertex* root) {
	root->fullReverse();
	vector<int> seq;
	root->dfs(seq);
	return seq;
}

inline int randInt(int minValue, int maxValue) {
	return minValue + rand() % (maxValue - minValue + 1);
}

const int MAX_SEQ_LEN = 131072 + 5;
const int MAX_CMD_LEN = 1000000 + 5;

int len;
int perm[MAX_SEQ_LEN];
int src_perm[MAX_SEQ_LEN];
int dst_perm[MAX_SEQ_LEN];

int rev_cnt;
pair<int, int> rev_arg[MAX_CMD_LEN];

void read() {
	scanf("%d", &len);
	for (int i = 0; i < len; ++i) scanf("%d", &src_perm[i]);
	for (int i = 0; i < len; ++i) scanf("%d", &dst_perm[i]);
}

void sort(int perm[]) {
	vector<int> seq(perm, perm + len);
	Vertex *root = buildTree(seq);
	for (int num = len; num >= 2; --num) {
		int index = getIndexOfMax(root);
		root = applyReversal(root, index, num);
		Vertex *leftChild, *rightChild;
		splitTrees(&leftChild, &rightChild, root, num - 1);
		root = leftChild;
		rev_arg[rev_cnt++] = make_pair(index - 1, num - 1);
	}
}

void solve() {
	static int where[MAX_SEQ_LEN];
	for (int i = 0; i < len; ++i) where[dst_perm[i]] = i + 1;
	for (int i = 0; i < len; ++i) perm[i] = where[src_perm[i]];
	
	sort(perm);
	printf("%d\n", rev_cnt);
	for (int i = 0; i < rev_cnt; ++i)
		printf("%d %d\n", rev_arg[i].first + 1, rev_arg[i].second + 1);
}

int main() {
	read();
	solve();
	return 0;
}